@@ -3,7 +3,6 @@ from itertools import cycle
 from textual.app import App, ComposeResult
 from textual.widgets import Static
 
-
 hellos = cycle(
     [
         "Hola",
@@ -34,7 +33,7 @@ class Hello(Static):
 
 
 class CustomApp(App):
-    CSS_PATH = "hello05.css"
+    CSS_PATH = "hello05.tcss"
 
     def compose(self) -> ComposeResult:
         yield Hello()
