@@ -6,12 +6,7 @@ import pytest
 
 from textual.app import App, ComposeResult
 from textual.widgets import OptionList
-from textual.widgets.option_list import (
-    DuplicateID,
-    Option,
-    OptionDoesNotExist,
-    Separator,
-)
+from textual.widgets.option_list import DuplicateID, Option, OptionDoesNotExist
 
 
 class OptionListApp(App[None]):
@@ -21,7 +16,7 @@ class OptionListApp(App[None]):
         yield OptionList(
             "0",
             Option("1"),
-            Separator(),
+            None,
             Option("2", disabled=True),
             None,
             Option("3", id="3"),
@@ -161,3 +156,13 @@ async def test_options_are_available_soon() -> None:
     option = Option("", id="some_id")
     option_list = OptionList(option)
     assert option_list.get_option("some_id") is option
+
+
+async def test_set_options():
+    """Test set_options method."""
+    async with OptionListApp().run_test() as pilot:
+        option_list = pilot.app.query_one(OptionList)
+        option_list.set_options(["foo", "bar"])
+        assert option_list.option_count == 2
+        assert option_list.get_option_at_index(0).prompt == "foo"
+        assert option_list.get_option_at_index(1).prompt == "bar"
